@@ -1,5 +1,7 @@
 import os
 import shutil
+import tempfile
+
 from pathlib import Path
 
 import pytest
@@ -9,7 +11,13 @@ from engine.config import Config
 
 @pytest.fixture
 def master() -> Path:
-    return Path.cwd() / "tests" / "resources" / "master.xlsx"
+    return Path.cwd() / "datamaps" / "tests" / "resources" / "master.xlsx"
+
+
+@pytest.fixture
+def temp_input_dir() ->  Path:
+    pth = tempfile.mkdtemp()
+    yield pth
 
 
 @pytest.fixture
